===========================================
机器学习框架
===========================================




.. toctree::
    :maxdepth: 1
    :caption: 示例教程


    训练和部署PyTorch模型<pytorch_mnist/pytorch_mnist>
    训练和部署XGBoost模型<xgboost_breast_cancer/xgboost_breast_cancer>
    训练和部署Tensorflow模型<tensorflow_image_classification/tensorflow_image_classification>
    基于HuggingFace BERT训练和部署文本分类模型<huggingface_bert/huggingface_bert>
    使用ModelScope ViT训练和部署图片分类模型<modelscope_vit/modelscope_vit>
